[PATCH 10/13] staging: iio: tsl2x7x: rename prx to prox for consistency

Brian Masney masneyb at onstation.org
Sat Apr 21 00:41:50 UTC 2018


The driver mostly uses the 'prox' naming convention for most of the
proximity settings, however prx_time and tsl2x7x_prx_gain was present.
This patch renames these to prox_time and tsl2x7x_prox_gain for
consistency with everything else in the driver.

The kernel documentation for prx_gain is corrected to prox_gain so that
it matches what is actually in the structure.

Signed-off-by: Brian Masney <masneyb at onstation.org>
---
 drivers/staging/iio/light/tsl2x7x.c | 12 ++++++------
 drivers/staging/iio/light/tsl2x7x.h |  6 +++---
 2 files changed, 9 insertions(+), 9 deletions(-)

diff --git a/drivers/staging/iio/light/tsl2x7x.c b/drivers/staging/iio/light/tsl2x7x.c
index 87b99deef7a8..a7b4fcba7935 100644
--- a/drivers/staging/iio/light/tsl2x7x.c
+++ b/drivers/staging/iio/light/tsl2x7x.c
@@ -203,7 +203,7 @@ static const struct tsl2x7x_lux *tsl2x7x_default_lux_table_group[] = {
 static const struct tsl2x7x_settings tsl2x7x_default_settings = {
 	.als_time = 219, /* 101 ms */
 	.als_gain = 0,
-	.prx_time = 254, /* 5.4 ms */
+	.prox_time = 254, /* 5.4 ms */
 	.prox_gain = 0,
 	.wait_time = 245,
 	.prox_config = 0,
@@ -230,7 +230,7 @@ static const s16 tsl2x7x_als_gain[] = {
 	120
 };
 
-static const s16 tsl2x7x_prx_gain[] = {
+static const s16 tsl2x7x_prox_gain[] = {
 	1,
 	2,
 	4,
@@ -594,7 +594,7 @@ static int tsl2x7x_chip_on(struct iio_dev *indio_dev)
 	u8 *dev_reg, reg_val;
 
 	/* Non calculated parameters */
-	chip->tsl2x7x_config[TSL2X7X_PRX_TIME] = chip->settings.prx_time;
+	chip->tsl2x7x_config[TSL2X7X_PRX_TIME] = chip->settings.prox_time;
 	chip->tsl2x7x_config[TSL2X7X_WAIT_TIME] = chip->settings.wait_time;
 	chip->tsl2x7x_config[TSL2X7X_PRX_CONFIG] = chip->settings.prox_config;
 
@@ -1021,7 +1021,7 @@ static int tsl2x7x_write_event_value(struct iio_dev *indio_dev,
 		if (chan->type == IIO_INTENSITY)
 			time = chip->settings.als_time;
 		else
-			time = chip->settings.prx_time;
+			time = chip->settings.prox_time;
 
 		y = (TSL2X7X_MAX_TIMER_CNT - time) + 1;
 		z = y * TSL2X7X_MIN_ITIME;
@@ -1090,7 +1090,7 @@ static int tsl2x7x_read_event_value(struct iio_dev *indio_dev,
 			time = chip->settings.als_time;
 			mult = chip->settings.als_persistence;
 		} else {
-			time = chip->settings.prx_time;
+			time = chip->settings.prox_time;
 			mult = chip->settings.prox_persistence;
 		}
 
@@ -1153,7 +1153,7 @@ static int tsl2x7x_read_raw(struct iio_dev *indio_dev,
 		if (chan->type == IIO_LIGHT)
 			*val = tsl2x7x_als_gain[chip->settings.als_gain];
 		else
-			*val = tsl2x7x_prx_gain[chip->settings.prox_gain];
+			*val = tsl2x7x_prox_gain[chip->settings.prox_gain];
 		ret = IIO_VAL_INT;
 		break;
 	case IIO_CHAN_INFO_CALIBBIAS:
diff --git a/drivers/staging/iio/light/tsl2x7x.h b/drivers/staging/iio/light/tsl2x7x.h
index 2c96f0b39b1e..408e5a89edb1 100644
--- a/drivers/staging/iio/light/tsl2x7x.h
+++ b/drivers/staging/iio/light/tsl2x7x.h
@@ -44,9 +44,9 @@ struct tsl2x7x_lux {
  *                          aperture effects.
  *  @wait_time:             Time between PRX and ALS cycles
  *                          in 2.7 periods
  *  @prx_time:              5.2ms prox integration time -
  *                          decrease in 2.7ms periods
  *  @prx_gain:              Proximity gain index
  *  @prox_config:           Prox configuration filters.
  *  @als_cal_target:        Known external ALS reading for
  *                          calibration.
@@ -68,7 +68,7 @@ struct tsl2x7x_settings {
 	int als_gain;
 	int als_gain_trim;
 	int wait_time;
-	int prx_time;
+	int prox_time;
 	int prox_gain;
 	int prox_config;
 	int als_cal_target;
@@ -44,9 +44,9 @@ struct tsl2x7x_lux {
  *  @wait_time:             Time between PRX and ALS cycles
  *                          in 2.7 periods
- *  @prx_time:              5.2ms prox integration time -
+ *  @prox_time:             5.2ms prox integration time -
  *                          decrease in 2.7ms periods
@@ -44,9 +44,9 @@ struct tsl2x7x_lux {
  *                          decrease in 2.7ms periods
- *  @prx_gain:              Proximity gain index
+ *  @prox_gain:             Proximity gain index
  *  @prox_config:           Prox configuration filters.
  *  @als_cal_target:        Known external ALS reading for
-- 
2.14.3



More information about the devel mailing list